Class: Cerberus::EnvCredentialsProvider
- Inherits:
-
Object
- Object
- Cerberus::EnvCredentialsProvider
- Defined in:
- lib/cerberus/env_credentials_provider.rb
Overview
The Environment variable credentials provider - looks for #CERBERUS_VAULT_TOKEN_ENV_KEY in env vars
Constant Summary collapse
- CERBERUS_VAULT_TOKEN_ENV_KEY =
"CERBERUS_TOKEN"
Instance Method Summary collapse
-
#getClientToken ⇒ Object
Look for the vault token in the env var.
Instance Method Details
#getClientToken ⇒ Object
Look for the vault token in the env var
17 18 19 20 21 22 23 24 25 26 |
# File 'lib/cerberus/env_credentials_provider.rb', line 17 def getClientToken tokenOption = ENV[CERBERUS_VAULT_TOKEN_ENV_KEY] if(tokenOption != nil) return tokenOption else raise Cerberus::Exception::NoValueError end end |